@@ -485,7 +485,9 @@ class _BaseClient(object):
     def _jsonrpc_retry_call(self, *args, **kwargs):
         try:
             return self._jsonrpc_call(*args, **kwargs)
-        except (requests.ReadTimeout, ServerError) as e:
+        except (requests.ReadTimeout,
+                UiAutomationNotConnectedError,
+                ServerError) as e:
             self.reset_uiautomator(str(e))  # uiautomator可能出问题了，强制重启一下
         except (NullObjectExceptionError,
                 NullPointerExceptionError,
